<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>FileControl</name>
    <message>
        <location filename="../src/filecontrol.cpp" line="781"/>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="785"/>
        <source>Exit fullscreen</source>
        <translation>Izhod iz celozaslonskega načina</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="789"/>
        <source>Extract text</source>
        <translation>Ekstrahiraj tekst</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="793"/>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="797"/>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="801"/>
        <location filename="../src/filecontrol.cpp" line="893"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="805"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="809"/>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="813"/>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="817"/>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="821"/>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="825"/>
        <source>Image info</source>
        <translation>Podatki o sliki</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="829"/>
        <source>Previous</source>
        <translation>Prejšnja</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="833"/>
        <source>Next</source>
        <translation>Naslednja</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="837"/>
        <source>Zoom in</source>
        <translation>Približaj</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="841"/>
        <source>Zoom out</source>
        <translation>Oddalji</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="845"/>
        <source>Open</source>
        <translation>Odpri</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="849"/>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="873"/>
        <source>Image Viewing</source>
        <translation>Prikazovanje slik</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="877"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="881"/>
        <source>Display shortcuts</source>
        <translation>Prikaži bližnjice</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="889"/>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="897"/>
        <source>Select all</source>
        <translation>Izberi vse</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="905"/>
        <source>Live Text</source>
        <translation>Besedilo v živo</translation>
    </message>
</context>
<context>
    <name>InformationDialog</name>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="74"/>
        <source>Basic info</source>
        <translation>Osnovni podatki</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="98"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="124"/>
        <source>Date captured</source>
        <translation>Datum slikanja</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="131"/>
        <source>Date modified</source>
        <translation>Datum spremembe</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="141"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="154"/>
        <source>Aperture</source>
        <translation>Zaslonka</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="162"/>
        <source>Exposure program</source>
        <translation>Program osvetlitve</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="169"/>
        <source>Focal length</source>
        <translation>Goriščna razdalja</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="175"/>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="182"/>
        <source>Exposure mode</source>
        <translation>Način osvetlitve</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="188"/>
        <source>Exposure time</source>
        <translation>Čas osvetlitve</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="194"/>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="201"/>
        <source>Flash compensation</source>
        <translation>Kompenzacija flasha</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="214"/>
        <source>Colorspace</source>
        <translation>Barvni model</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="221"/>
        <source>Metering mode</source>
        <translation>Način meritve</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="228"/>
        <source>White balance</source>
        <translation>Temperatura beline</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="246"/>
        <source>Lens model</source>
        <translation>Model objektiva</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="87"/>
        <source>File name</source>
        <translation>Ime datoteke</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="105"/>
        <source>Dimensions</source>
        <translation>Dimenzije</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="112"/>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="207"/>
        <source>Max aperture</source>
        <translation>Največja zaslonka</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="239"/>
        <source>Device model</source>
        <translation>Model naprave</translation>
    </message>
</context>
<context>
    <name>LiveTextWidget</name>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="155"/>
        <source>Copy (Ctrl+C)</source>
        <translation>Kopiraj (Ctrl+C)</translation>
    </message>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="172"/>
        <source>Select all (Ctrl+A)</source>
        <translation>Izberi vse (Ctrl+A)</translation>
    </message>
</context>
<context>
    <name>MainStack</name>
    <message>
        <location filename="../qml/MainStack.qml" line="129"/>
        <source>Select pictures</source>
        <translation>Izberi slike</translation>
    </message>
</context>
<context>
    <name>NonexistImageDelegate</name>
    <message>
        <location filename="../qml/ImageDelegate/NonexistImageDelegate.qml" line="43"/>
        <source>Image file not found</source>
        <translation>Slika ni bila najdena</translation>
    </message>
</context>
<context>
    <name>OpenImageWidget</name>
    <message>
        <location filename="../qml/OpenImageWidget.qml" line="35"/>
        <source>Open Image</source>
        <translation>Odpri sliko</translation>
    </message>
</context>
<context>
    <name>PropertyActionItemDelegate</name>
    <message>
        <location filename="../qml/InformationDialog/PropertyActionItemDelegate.qml" line="95"/>
        <source>The file already exists, please use another name</source>
        <translation>Datoteka že obstaja. Izberite drugo ime</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Image Viewer</source>
        <translation>Deepin pregledovalnik slik</translation>
    </message>
    <message>
        <location filename="../src/unionimage/unionimage_global.h" line="102"/>
        <source>day</source>
        <translation>dan</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Pregledovalnik slik je orodje za prikazovanje slik z modernim vmesnikom in mehkim delovanjem.</translation>
    </message>
</context>
<context>
    <name>ReName</name>
    <message>
        <location filename="../qml/ReName.qml" line="70"/>
        <source>Input a new name</source>
        <translation>Vnesite novo ime</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="85"/>
        <source>The file already exists, please use another name</source>
        <translation>Datoteka že obstaja. Izberite drugo ime</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="141"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="123"/>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
</context>
<context>
    <name>RemoveDialog</name>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="71"/>
        <source>Cannot move &quot;%1&quot; to the trash. Do you want to permanently delete it?</source>
        <translation>Ne moremo premakniti &quot;%1&quot; v koš. Zelите ga izbrisati trajno?</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="89"/>
        <source>This action cannot be undone</source>
        <translation>Ta dejanje se ne more ponovno uraditi</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="101"/>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="111"/>
        <source>Confirm</source>
        <translation>Potrdi</translation>
    </message>
</context>
<context>
    <name>SliderShow</name>
    <message>
        <location filename="../qml/SliderShow.qml" line="155"/>
        <source>Previous</source>
        <translation>Prejšnja</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <location filename="../qml/SliderShow.qml" line="223"/>
        <source>Pause</source>
        <translation>Pavza</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <location filename="../qml/SliderShow.qml" line="223"/>
        <source>Play</source>
        <translation>Predvajaj</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="188"/>
        <source>Next</source>
        <translation>Naslednja</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="203"/>
        <location filename="../qml/SliderShow.qml" line="244"/>
        <source>Exit</source>
        <translation>Izhod</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="173"/>
        <source>Next</source>
        <translation>Naslednja</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="148"/>
        <source>Previous</source>
        <translation>Prejšnja</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="209"/>
        <source>Original size</source>
        <translation>Velikost originala</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="227"/>
        <source>Fit to window</source>
        <translation>Prilagodi oknu</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="244"/>
        <source>Rotate</source>
        <translation>Zavrti</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="517"/>
        <source>Extract text</source>
        <translation>Ekstrahiraj tekst</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="536"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>ViewRightMenu</name>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Fullscreen</source>
        <translation>Celozaslonski način</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Exit fullscreen</source>
        <translation>Izhod iz celozaslonskega načina</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="57"/>
        <source>Print</source>
        <translation>Tiskanje</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="76"/>
        <source>Extract text</source>
        <translation>Ekstrahiraj tekst</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="96"/>
        <source>Slide show</source>
        <translation>Diaprojekcija</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="117"/>
        <source>Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="137"/>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="156"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="183"/>
        <source>Rotate clockwise</source>
        <translation>Zasukaj v desno</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="203"/>
        <source>Rotate counterclockwise</source>
        <translation>Zasukaj v levo</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Show navigation window</source>
        <translation>Pokaži navigacijsko okno</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Hide navigation window</source>
        <translation>Skrij navigacijsko okno</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="243"/>
        <source>Set as wallpaper</source>
        <translation>Nastavi za ozadje</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="263"/>
        <source>Display in file manager</source>
        <translation>Prikaži v upravitelju datotek</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="280"/>
        <source>Image info</source>
        <translation>Podatki o sliki</translation>
    </message>
</context>
<context>
    <name>ViewTopTitle</name>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="189"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Pregledovalnik slik je orodje za prikazovanje slik z modernim vmesnikom in mehkim delovanjem.</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="191"/>
        <source>Image Viewer</source>
        <translation>Deepin pregledovalnik slik</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="167"/>
        <source>Open image</source>
        <translation>Odpri sliko</translation>
    </message>
</context>
</TS>
